@@ -26,6 +26,7 @@
 #include "gcal-debug.h"
 #include "gcal-enums.h"
 #include "gcal-log.h"
+#include "gcal-night-light-monitor.h"
 #include "gcal-shell-search-provider.h"
 #include "gcal-weather-service.h"
 #include "gcal-window.h"
@@ -53,13 +54,11 @@ struct _GcalApplication
   GcalTimeFormat      time_format;
 
   GcalWeatherService *weather_service;
-
   GcalShellSearchProvider *search_provider;
-};
+  GcalNightLightMonitor *night_light_monitor;
 
-static void     gcal_application_create_new_event     (GSimpleAction           *new_event,
-                                                       GVariant                *parameter,
-                                                       gpointer                 app);
+  GcalClock          *clock;
+};
 
 static void     gcal_application_launch_search        (GSimpleAction           *search,
                                                        GVariant                *parameter,
@@ -111,7 +110,6 @@ static GOptionEntry gcal_application_goptions[] = {
 };
 
 static const GActionEntry gcal_app_entries[] = {
-  { "new",    gcal_application_create_new_event },
   { "sync",   gcal_application_sync },
   { "search", gcal_application_launch_search },
   { "about",  gcal_application_show_about },
@@ -121,6 +119,7 @@ static const GActionEntry gcal_app_entries[] = {
 enum
 {
   PROP_0,
+  PROP_CLOCK,
   PROP_MANAGER,
   PROP_TIME_FORMAT,
   PROP_WEATHER_SERVICE,
@@ -229,8 +228,10 @@ gcal_application_finalize (GObject *object)
   g_clear_pointer (&self->initial_date, g_free);
   g_clear_pointer (&self->uuid, g_free);
   g_clear_object (&self->colors_provider);
+  g_clear_object (&self->clock);
   g_clear_object (&self->desktop_settings);
   g_clear_object (&self->manager);
+  g_clear_object (&self->night_light_monitor);
   g_clear_object (&self->provider);
   g_clear_object (&self->search_provider);
   g_clear_object (&self->weather_service);
@@ -250,6 +251,10 @@ gcal_application_get_property (GObject    *object,
 
   switch (property_id)
     {
+    case PROP_CLOCK:
+      g_value_set_object (value, self->clock);
+      break;
+
     case PROP_MANAGER:
       g_value_set_object (value, self->manager);
       break;
@@ -290,6 +295,9 @@ gcal_application_activate (GApplication *application)
                                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 2);
     }
 
+  if (!self->night_light_monitor)
+    self->night_light_monitor = gcal_night_light_monitor_new (self->manager);
+
   if (!self->window)
     {
       if (!self->initial_date)
@@ -506,6 +514,12 @@ gcal_application_class_init (GcalApplicationClass *klass)
   application_class->dbus_register = gcal_application_dbus_register;
   application_class->dbus_unregister = gcal_application_dbus_unregister;
 
+  properties[PROP_CLOCK] = g_param_spec_object ("clock",
+                                                "Clock",
+                                                "The internal clock of Calendar",
+                                                GCAL_TYPE_CLOCK,
+                                                G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
   properties[PROP_MANAGER] = g_param_spec_object ("manager",
                                                   "The manager object",
                                                   "The manager object",
@@ -533,6 +547,7 @@ gcal_application_init (GcalApplication *self)
 {
   g_application_add_main_option_entries (G_APPLICATION (self), gcal_application_goptions);
 
+  self->clock = gcal_clock_new ();
   self->manager = gcal_manager_new ();
   g_signal_connect_swapped (self->manager, "source-added", G_CALLBACK (process_sources), self);
   g_signal_connect_swapped (self->manager, "source-changed", G_CALLBACK (process_sources), self);
@@ -540,15 +555,6 @@ gcal_application_init (GcalApplication *self)
   self->search_provider = gcal_shell_search_provider_new (self->manager);
 }
 
-static void
-gcal_application_create_new_event (GSimpleAction *new_event,
-                                   GVariant      *parameter,
-                                   gpointer       app)
-{
-  GcalApplication *self = GCAL_APPLICATION (app);
-  gcal_window_new_event (GCAL_WINDOW (self->window));
-}
-
 static void
 gcal_application_sync (GSimpleAction *sync,
                        GVariant      *parameter,
@@ -726,6 +732,14 @@ gcal_application_set_initial_date (GcalApplication *self,
 {
   g_return_if_fail (GCAL_IS_APPLICATION (self));
 
-  g_clear_pointer (&self->initial_date, g_date_time_unref);
+  g_clear_pointer (&self->initial_date, g_free);
   self->initial_date = datetime_to_icaltime (initial_date);
 }
+
+GcalClock*
+gcal_application_get_clock (GcalApplication *self)
+{
+  g_return_val_if_fail (GCAL_IS_APPLICATION (self), NULL);
+
+  return self->clock;
+}
