@@ -126,7 +126,6 @@ struct _GcalWindow
   GtkWidget          *today_button;
   GtkWidget          *forward_button;
   GtkWidget          *views_switcher;
-  GtkWidget          *win_menu_stack;
 
   /* new event popover widgets */
   GtkWidget          *quick_add_popover;
@@ -191,8 +190,6 @@ enum
   N_PROPS
 };
 
-#define SAVE_GEOMETRY_ID_TIMEOUT 100 /* ms */
-
 #define gcal_window_add_accelerator(app,action,...) {\
   const gchar *tmp[] = {__VA_ARGS__, NULL};\
   gtk_application_set_accels_for_action (GTK_APPLICATION (app), action, tmp);\
@@ -931,14 +928,6 @@ window_state_changed (GtkWidget *widget,
   return FALSE;
 }
 
-static void
-on_popover_menu_visible_cb (GtkWidget  *widget,
-                            GParamSpec *pspec,
-                            GcalWindow *self)
-{
-  gtk_stack_set_visible_child_name (GTK_STACK (self->win_menu_stack), "main-menu");
-}
-
 static void
 edit_event (GcalQuickAddPopover *popover,
             GcalEvent           *event,
@@ -1481,7 +1470,6 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_overlay);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_stack);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_switcher);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, win_menu_stack);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, weather_settings);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, week_view);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, year_view);
@@ -1499,8 +1487,6 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, view_changed);
   gtk_widget_class_bind_template_callback (widget_class, date_updated);
 
-  gtk_widget_class_bind_template_callback (widget_class, on_popover_menu_visible_cb);
-
   /* Event removal related */
   gtk_widget_class_bind_template_callback (widget_class, hide_notification);
   gtk_widget_class_bind_template_callback (widget_class, remove_event);
@@ -1606,46 +1592,6 @@ gcal_window_new_with_date (GcalApplication *app,
                        NULL);
 }
 
-/* new-event interaction: first variant */
-/**
- * gcal_window_new_event:
- * @self: a #GcalWindow
- *
- * Makes #GcalWindow create a new event.
- */
-void
-gcal_window_new_event (GcalWindow *self)
-{
-  g_autoptr (GDateTime) start_date, end_date;
-
-  /* 1st and 2nd steps */
-  set_new_event_mode (self, TRUE);
-
-  start_date = g_date_time_new_now_local ();
-
-  /* adjusting dates according to the actual view */
-  switch (self->active_view)
-    {
-    case GCAL_WINDOW_VIEW_DAY:
-    case GCAL_WINDOW_VIEW_WEEK:
-      end_date = g_date_time_add_hours (start_date, 1);
-      break;
-
-    case GCAL_WINDOW_VIEW_MONTH:
-    case GCAL_WINDOW_VIEW_YEAR:
-      end_date = g_date_time_add_days (start_date, 1);
-      break;
-
-    case GCAL_WINDOW_VIEW_LIST:
-    case GCAL_WINDOW_VIEW_SEARCH:
-    default:
-      end_date = g_date_time_add_days (start_date, 1);
-      break;
-    }
-
-  create_event_detailed_cb (NULL, start_date, end_date, self);
-}
-
 /**
  * gcal_window_set_search_mode:
  * @self: a #GcalWindow
